@@ -21,7 +21,7 @@
 #' @return A matrix with a column for the crps (ibs) at every requested time
 #' point and a row for each model
 #' @author Thomas A. Gerds \email{tag@@biostat.ku.dk}
-#' @seealso \code{\link{pec}}
+#' @seealso \link{pec}
 #' @references E. Graf et al.  (1999), Assessment and comparison of prognostic
 #' classification schemes for survival data. Statistics in Medicine, vol 18,
 #' pp= 2529--2545.
@@ -34,7 +34,7 @@
 #' library(prodlim)
 #' library(survival)
 #' dat=SimSurv(100)
-#' pmodel=coxph(Surv(time,status)~X1+X2,data=dat)
+#' pmodel=coxph(Surv(time,status)~X1+X2,data=dat,x=TRUE,y=TRUE)
 #' perror=pec(list(Cox=pmodel),Hist(time,status)~1,data=dat)
 #' 
 #' ## cumulative prediction error
@@ -51,7 +51,7 @@ crps <- function(object,
                  what,
                  times,
                  start){
-  stopifnot(class(object)[1] == "pec")
+    stopifnot(inherits(x = object,what = "pec"))
   
   # {{{find the prediction models
   if (missing(models)) models <- 1:length(object$models)
