@@ -35,21 +35,28 @@
 #' the form \code{legend.x=val} where x is the name of the argument and val the
 #' desired value. See also Details.
 #' @param percent Logical. If \code{TRUE} the y-axis is labeled in percent.
-#' @param \dots Parameters that are filtered by \code{\link{SmartControl}} and
-#' then passed to the functions: \code{\link{plot}}, \code{\link{axis}},
-#' \code{\link{legend}}.
+#' @param \dots Parameters that are filtered by \link[prodlim]{SmartControl} and
+#' then passed to the functions: \code{plot}, \code{axis},
+#' \code{legend}.
 #' @return The (invisible) object.
 #' @author Ulla B. Mogensen \email{ulmo@@biostat.ku.dk}, Thomas A. Gerds
 #' \email{tag@@biostat.ku.dk}
-#' @seealso \code{\link{predictEventProb}}\code{\link{prodlim}}
+#' @seealso \link{predictEventProb}, \link[prodlim]{prodlim}
 #' @references Ulla B. Mogensen, Hemant Ishwaran, Thomas A. Gerds (2012).
 #' Evaluating Random Forests for Survival Analysis Using Prediction Error
-#' Curves. Journal of Statistical Software, 50(11), 1-23. URL
-#' https://www.jstatsoft.org/v50/i11.
+#' Curves. Journal of Statistical Software, 50(11), 1-23. DOI
+#' 10.18637/jss.v050.i11
 #' @keywords survival
 #' @examples
 #' 
-#' # generate some competing risk data
+#' # competing risk data
+#' library(riskRegression)
+#' library(pec)
+#' set.seed(9)
+#' d=sampleData(80)
+#' csc1 <- CSC(Hist(time,event)~X1+X8, data=d)
+#' nd=sampleData(3)
+#' plotPredictEventProb(csc1, newdata=nd, cause=1, col=1:3)
 #' 
 #' @export
 plotPredictEventProb <- function(x,
@@ -77,8 +84,8 @@ plotPredictEventProb <- function(x,
 
   if(missing(times)){
     # formula
-    formula <- eval(x$call$formula)
-    if (match("formula",class(formula),nomatch=0)==0)
+      formula <- eval(x$call$formula)
+    if (!inherits(x = formula,what = "formula"))
       stop("Argument formula is missing.")
     # find data
     data <- eval(x$call$data)
