@@ -36,13 +36,13 @@
 #' the form \code{legend.x=val} where x is the name of the argument and val the
 #' desired value. See also Details.
 #' @param percent Logical. If \code{TRUE} the y-axis is labeled in percent.
-#' @param \dots Parameters that are filtered by \code{\link{SmartControl}} and
-#' then passed to the functions: \code{\link{plot}}, \code{\link{axis}},
-#' \code{\link{legend}}.
+#' @param \dots Parameters that are filtered by \link[prodlim]{SmartControl} and
+#' then passed to the functions: \code{plot}, \code{axis},
+#' \code{legend}.
 #' @return The (invisible) object.
 #' @author Ulla B. Mogensen \email{ulmo@@biostat.ku.dk}, Thomas A. Gerds
 #' \email{tag@@biostat.ku.dk}
-#' @seealso \code{\link{predictSurvProb}}\code{\link{prodlim}}
+#' @seealso \link{predictSurvProb}, \link[prodlim]{prodlim}
 #' @references Ulla B. Mogensen, Hemant Ishwaran, Thomas A. Gerds (2012).
 #' Evaluating Random Forests for Survival Analysis Using Prediction Error
 #' Curves. Journal of Statistical Software, 50(11), 1-23. DOI
@@ -53,7 +53,8 @@
 #' # generate some survival data
 #' library(prodlim)
 #' d <- SimSurv(100)
-#' # then fit a Cox model 
+#' # then fit a Cox model
+#' library(survival)
 #' library(rms)
 #' coxmodel <- cph(Surv(time,status)~X1+X2,data=d,surv=TRUE)
 #' # plot predicted survival probabilities for all time points
@@ -89,7 +90,7 @@ plotPredictSurvProb <- function(x,
   if(missing(times)){
     # formula
     formula <- eval(x$call$formula)
-    if (match("formula",class(formula),nomatch=0)==0)
+    if (!inherits(x = formula,what = "formula"))
       stop("Argument formula is missing.")
     # find data
     data <- eval(x$call$data)
