@@ -15,7 +15,7 @@
 #' @param \dots Not used
 #' @return The first argument in the invisible cloak.
 #' @author Thomas A. Gerds \email{tag@@biostat.ku.dk}
-#' @seealso \code{\link{pec}}
+#' @seealso \link{pec}
 #' @keywords survival
 #' @export
 print.pec <- function(x,
@@ -27,7 +27,7 @@ print.pec <- function(x,
     # {{{ echo models
     cat("Prediction models:\n\n")
     printModels <- sapply(x$models,function(m){
-        if (class(m) %in% c("character","call"))
+        if (inherits(x = m,what = "character")||inherits(x = m,what = "call"))
             m
         else
             if (inherits(try(m$call,silent=TRUE),what="try-error"))
